/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * ivrtest Application For Asterisk
 *
 * Copyright (C) 2005, Anthony Minessale II
 *
 * Anthony Minessale II <anthmct@yahoo.com>
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License
 */

#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/module.h>
#include <asterisk/lock.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <asterisk/ivr_api.h>

static char *tdesc = "ivrtest";
static char *app = "ivrtest";
static char *synopsis = "ivrtest";
static char *desc = "";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;



struct myobj {
	char a[120];
	int x;
};


ast_ivr_menu_t *main_menu, *sub_menu;

static ast_ivr_action_t demo_callback(struct ast_ivr_menu *menu, char *buf, size_t len, void *obj) 
{
	struct myobj *myo = obj; /* vanilla obj to pass arounf for saving state. */
	strncpy(buf, "confcall/dk-kicked", len);
	return IVR_ACTION_PLAYSOUND;
}

static int ivrtest_exec(struct ast_channel *chan, void *data)
{
	int res=0;
	struct localuser *u;

	struct myobj myo;


	strncpy(myo.a, "hi", sizeof(myo.a));
	myo.x = 100;

	if (!data) {
		ast_log(LOG_WARNING, "ivrtest requires an argument\n");
		return -1;
	}
	LOCAL_USER_ADD(u);
	
	/* myo will be passed around to the callbacks if any are binded */
	ast_ivr_menu_execute(chan, main_menu, NULL, &myo);
	
	LOCAL_USER_REMOVE(u);
	return res;
}

int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	if(main_menu)
		ast_ivr_menu_free_stack(main_menu);

	return ast_unregister_application(app);
}

int load_module(void)
{
	main_menu = ast_ivr_menu_init(NULL, "main_menu", "demo-thanks", "beep", "beeperr", 10000, 10, 1, 0);

	ast_ivr_menu_bind_function(main_menu, demo_callback ,"1");
	ast_ivr_menu_bind_action(main_menu, IVR_ACTION_DIE, NULL, "2");
	ast_ivr_menu_bind_action(main_menu, IVR_ACTION_PLAYSOUND, "vm-goodbye", "3");
	ast_ivr_menu_bind_action(main_menu, IVR_ACTION_EXECMENU, "sub_menu", "4");
	ast_ivr_menu_bind_action(main_menu, IVR_ACTION_TRANSFER, "3910|s|1", "5");
	

	sub_menu = ast_ivr_menu_init(main_menu, "sub_menu", "confcall/pac-kicked", NULL, "beeperr", 10000, 10, 1, 0);

	ast_ivr_menu_bind_action(sub_menu, IVR_ACTION_PLAYSOUND, "vm-goodbye", "1");
	ast_ivr_menu_bind_action(sub_menu, IVR_ACTION_PLAYSOUND, "demo-thanks", "2");
	ast_ivr_menu_bind_action(sub_menu, IVR_ACTION_BACK, NULL, "3");
	ast_ivr_menu_bind_action(sub_menu, IVR_ACTION_EXECAPP, "SayDigits|1234", "4");
	ast_ivr_menu_bind_action(sub_menu, IVR_ACTION_TOMAIN, NULL, "5");
	

	return ast_register_application(app, ivrtest_exec, synopsis, desc);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}

